<?php session_start();
// Verify if the request is POST and an Ajax call
if ($_SERVER['REQUEST_METHOD'] === 'POST' && (isset($_SERVER['HTTP_X_REQUESTED_WITH']) && $_SERVER['HTTP_X_REQUESTED_WITH'] === 'XMLHttpRequest')) {
    // Include the configuration file
    require("config.php");

    // Initialize response array and set Content-Type
    $response = [];
    header('Content-Type: application/json');

    // Sanitize the POST data
    $email = filter_var($_POST['email'], FILTER_SANITIZE_EMAIL);
    $password = filter_var($_POST['password'], FILTER_SANITIZE_STRING);

    // Perform validations
    if (empty($email) || empty($password)) {
        http_response_code(422);
        $response['message'] = 'Both email and password are required.';
    }
    else {
        // Prepare, bind, and execute SQL statement
        $stmt = mysqli_prepare($conn, "SELECT * FROM tbl_users WHERE email = ? AND password = ?");
        mysqli_stmt_bind_param($stmt, "ss", $email, $password);
        mysqli_stmt_execute($stmt);

        // Validate credentials
        $result = mysqli_stmt_get_result($stmt);
        if (mysqli_num_rows($result) != 1) {
            http_response_code(401);
            $response['message'] = 'Invalid email or password.';
        }

        // Fetch user details, and store it in session
        $userData = mysqli_fetch_assoc($result);

        // Check the status here
        if ($userData['status'] === 'Unverified') {
            http_response_code(403);
            $response['message'] = 'Your account is not verified.';
        } elseif ($userData['status'] === 'Disabled') {
            http_response_code(403);
            $response['message'] = 'Your account is disabled.';
        } elseif ($userData['status'] === 'Verified') {
            $_SESSION['userdata'] = $userData;
        } else {
            http_response_code(500);
            $response['message'] = 'An unknown error occurred.';
        }

        // Close resources
        mysqli_stmt_close($stmt);
        mysqli_close($conn);
    }
    // Output the JSON response
    echo json_encode($response);
    exit;
}
?>
<!-- Author: w3schools.in
URL: https://www.w3schools.in/javascript/examples/php-mysql-and-ajax-secure-login-system
license: Free to use without republishing.
https://www.w3schools.in/page/copyright -->
<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="utf-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>PHP, MySQL, and Ajax Secure Login System Demo</title>
    <link href="https://cdn.jsdelivr.net/npm/bootstrap@5.3.2/dist/css/bootstrap.min.css" rel="stylesheet" integrity="sha384-T3c6CoIi6uLrA9TneNEoa7RxnatzjcDSCmG1MXxSR1GAsXEV/Dwwykc2MPK8M2HN" crossorigin="anonymous">
    <script>
        document.addEventListener("DOMContentLoaded", () => {
            const loginForm = document.getElementById("loginForm");
            const emailError = document.getElementById("emailError");
            const passwordError = document.getElementById("passwordError");
            const loginError = document.getElementById("loginError");

            document.getElementById("loginButton").addEventListener("click", () => {
                if (!loginForm.checkValidity()) {
                    emailError.textContent = loginForm.email.checkValidity() ? "" : loginForm.email.validationMessage;
                    passwordError.textContent = loginForm.password.checkValidity() ? "" : loginForm.password.validationMessage;
                    return;
                }

                const xhr = new XMLHttpRequest();
                const email = document.getElementById("email").value;
                const password = document.getElementById("password").value;

                xhr.open("POST", "", true);
                xhr.setRequestHeader("Content-Type", "application/x-www-form-urlencoded");
                xhr.setRequestHeader("X-Requested-With", "XMLHttpRequest");
                xhr.onreadystatechange = () => {
                    if (xhr.readyState === 4) {
                        const response = JSON.parse(xhr.responseText);
                        if (xhr.status === 200) {
                            window.location.href = "dashboard.php";
                    return; // Successful login
                }
                loginError.textContent = xhr.status === 500 ? "Something went wrong on the server. Please try again later." : response.message;
            }
        };
        xhr.send(`email=${email}&password=${password}`);
    });
        });

    </script>
</head>
<body>
    <?php if(!isset($_GET['iframe'])){?>
    <!-- Header -->
    <header class="container-fluid bg-light">
        <nav class="row">
            <div class="col col-md-auto" style="height:90px;">
                <div class="h-100 d-flex justify-content-center align-items-center">
                    <a class="navbar-brand mx-3" href="https://www.w3schools.in/" title="W3schools Home"><img id="logo" alt="w3schools logo" class="d-inline-block align-text-middle" src="https://www.w3schools.in/wp-content/uploads/w3schools-logo.png" width="170" height="57"></a> Demo Program
                </div>
            </div>
            <div class="col d-none d-lg-block" style="height:90px;"><div id="ezoic-pub-ad-placeholder-126"></div></div>
        </nav>
    </header>
    <?php } ?>
    <!-- Top bar -->
    <div class="container-fluid shadow-sm border-bottom mb-4">
        <div class="row aligh-items-center">
            <div class="col">
                <nav class="navbar navbar-light">
                    <a class="btn btn-sm btn-light me-2" href="php-mysql-and-ajax-secure-login-system.zip" title="Download Demo Files"><svg class="svg-icon" viewBox="0 0 24 24">
                    <path d="M21 15v4a2 2 0 0 1-2 2H5a2 2 0 0 1-2-2v-4"></path>
                <polyline points="7 10 12 15 17 10"></polyline>
            <line x1="12" y1="15" x2="12" y2="3"></line>
        </svg></a>

        <?php if(isset($_GET['iframe'])){?>
        <a class="btn btn-sm btn-light me-2" href="<?php echo $_SERVER['REQUEST_SCHEME'] .'://'. $_SERVER['HTTP_HOST']  . explode('?', $_SERVER['REQUEST_URI'], 2)[0]; ?>" target="_blank" title="Open in new window"><svg class="svg-icon" viewBox="0 0 24 24">
            <path d="M18 13v6a2 2 0 0 1-2 2H5a2 2 0 0 1-2-2V8a2 2 0 0 1 2-2h6"></path>
            <polyline points="15 3 21 3 21 9"></polyline>
            <line x1="10" y1="14" x2="21" y2="3"></line>
        </svg></a>
        <?php } ?>

    </nav>
</div>
</div>
</div>
<!-- Main -->
<div class="container" style="max-width:600px">
<?php if(!isset($_GET['iframe'])){?>
<div class="text-center mb-5">
<h1 class="fw-bolder mb-0">PHP, MySQL, and Ajax Login System Demo</h1>
<p><a href="https://www.w3schools.in/" target="_blank">w3schools.in</a></p>
</div>
<?php } ?>
<h3>Login Form</h3>
<div class="card shadow-sm mb-3">
<div class="card-body">
    <form id="loginForm">
        <div class="mb-3">
            <label for="email" class="form-label">Email</label>
            <input type="email" name="email" id="email" class="form-control" placeholder="Your email address" required>
            <span id="emailError" class="text-danger small"></span>
        </div>
        <div class="mb-3">
            <label for="password" class="form-label">Password</label>
            <input type="password" name="password" id="password" class="form-control" required>
            <span id="passwordError" class="text-danger small"></span>
        </div>
        <input type="button" id="loginButton" class="btn btn-success mb-3" value="Login">
        <div id="loginError" class="text-danger small"></div>
    </form>
</div>
</div>

<!-- User Information Table -->
<h3>Sample User Data</h3>
<p>Refer to the sample users below for testing the login system.</p>
<table class="table table-sm mb-3 small">
<thead>
    <tr>
        <th>ID</th>
        <th>Name</th>
        <th>Email</th>
        <th>Password</th>
        <th>Status</th>
    </tr>
</thead>
<tbody>
<!-- Sample User Data -->
<!-- Passwords are displayed for demonstration purposes. -->
    <tr>
        <td>1</td>
        <td>Alex</td>
        <td>alex@example.com</td>
        <td>alex123</td>
        <td class="text-success">Verified</td>
    </tr>
    <tr>
        <td>2</td>
        <td>Emily Watson</td>
        <td>emily@example.com</td>
        <td>emily123</td>
        <td class="text-success">Verified</td>
    </tr>
    <tr>
        <td>3</td>
        <td>Anita Sharma</td>
        <td>anita@example.com</td>
        <td>anita123</td>
        <td class="text-danger">Disabled</td>
    </tr>
    <tr>
        <td>4</td>
        <td>John Doe</td>
        <td>john@example.com</td>
        <td>john123</td>
        <td class="text-danger">Unverified</td>
    </tr>
</tbody>
</table>
</body>
</html>